@@ -3,6 +3,7 @@ from subprocess import PIPE, check_call
 import os
 import random
 import socket
+import logging
 
 from qds_ops.tparty.knife import Knife
 from qds_ops.utils.ssh_tunnel import SSHTunnel
@@ -54,7 +55,7 @@ class RDS():
     @staticmethod
     def checkport(port):
         s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-        result = s.connect_ex(('127.0.0.1', 3306))
+        result = s.connect_ex(('127.0.0.1', port))
         s.close()
 
         return result != 0
@@ -87,29 +88,29 @@ class RDS():
         mysql_cmd = ["mysql", "-u", creds["username"],
                      "-p%s" % creds["password"], "-h", hostname, "-P", str(port), "--prompt",
                      "%s>\_" % args.environment]
+        logging.debug(" ".join(mysql_cmd))
+
         if not args.autocomplete:
             mysql_cmd.append("-A")
 
         mysql = check_call(mysql_cmd)
 
-        if pemfile is not None:
-            os.unlink(pemfile)
 
     def tunnel(self, args):
         args.tunnel = True
         self.connect(args)
 
     @staticmethod
-    def run_query(args, sql_query):
+    def run_query(env, tunnel, sql_query):
         knife = Knife()
-        list = knife.search(args.environment, "web")
-        creds = knife.get_credentials(args.environment)
+        list = knife.search(env, "web")
+        creds = knife.get_credentials(env)
         hostname = creds["host"]
         port = 3306
         # Setup a tunnel
-        if args.tunnel:
+        if tunnel:
             port = random.randrange(1, 1000) + 33000
-            pemfile = knife.get_pemfile(args.environment)
+            pemfile = knife.get_pemfile(env)
             counter = 1
             while not RDS.checkport(port) and counter < 5:
                 port = random.randrange(1, 1000) + 33000
@@ -129,4 +130,4 @@ class RDS():
             rows = cur.fetchone()
             return rows
         except MySQLdb.Error, e:
-            print "Error %d: %s" % (e.args[0], e.args[1])
\ No newline at end of file
+            logging.error("Error %d: %s" % (e.args[0], e.args[1]))
