@@ -1,10 +1,9 @@
 import json
-from subprocess import Popen
-from subprocess import check_call
-import os
+import subprocess
 import signal
 
 from qds_ops.tparty.knife import Knife
+from qds_ops.utils.deploy_utils import DeployUtils
 
 
 class Tier(object):
@@ -50,28 +49,11 @@ class Tier(object):
                                                     help="Run deploy in %s tier" % self.tier)
         self.deploy_parser.add_argument("-m", "--module", dest="module", choices=module_choices,
                                    default="all", help="Deploy module to %s" % (self.tier))
-        self.deploy_parser.add_argument("-r", "--no-rolling", dest="rolling",
-                                   default=True, action="store_false",
-                                   help="Don't do rolling deploy to %s" % (self.tier))
-        self.deploy_parser.add_argument("-t", "--stop-djs-at-start", dest="stopdjs",
-                                   default=False, action="store_true",
-                                   help="At start of rolling deploy, stop DJs on current nodes")
-        self.deploy_parser.add_argument("-c", "--run-common-stuff-recipe", dest="commstuff",
-                                   default=False, action="store_true", help="Run common stuff at start of deploy")
-        self.deploy_parser.add_argument("-d", "--no-djrestart", dest="djrestart",
-                                   default=True, action="store_false", help="Don't do DJ restart on %s" % (self.tier))
-        self.deploy_parser.add_argument("-s", "--srcpath", dest="src_path", required=True,
-                                   default="~/src/", help="Root src directory")
         self.deploy_parser.set_defaults(func=self.deploy)
 
     def deploy(self, args):
         knife = Knife()
-        chef_command = ""
-        if args.module == "all":
-            chef_command = "sudo chef-client -j /etc/chef/first-boot.json -E %s" % (args.environment)
-        else:
-            runlist = '{"run_list":["recipe[webslave::deploy_%s]"]}' % (args.module)
-            chef_command = "echo '%s' > /tmp/runlist; sudo chef-client -j /tmp/runlist" % (runlist)
+        chef_command = DeployUtils.get_chef_command_for_module(args.module, args.environment)
 
         knife.reap_instances(args)
         #Entering critical region. Interruption in this region causes a lot of grief
@@ -82,11 +64,7 @@ class Tier(object):
         signal.signal(signal.SIGQUIT, signal.SIG_IGN)
 
         temp = knife.get_pemfile(args.environment)
-        search_string = "chef_environment:%s AND qubole_tier:%s" % (args.environment, self.tier)
-        p = Popen(
-            ["knife", "ssh", search_string, chef_command, "-x", "ec2-user", "-i", temp, "-a", "ec2.public_hostname",
-             "--no-host-key-verify"])
-        retcode = p.wait()
+        retcode = DeployUtils.run_chef_command(chef_command, args.environment, self.tier, temp, "")
 
         signal.signal(signal.SIGINT, signal.SIG_DFL)
         signal.signal(signal.SIGHUP, signal.SIG_DFL)
@@ -129,6 +107,4 @@ class Tier(object):
             list = knife.search(args.environment, self.tier)
             host = list[0]
 
-        check_call(["ssh", "-i", pemfile, "ec2-user@%s" % host])
-        if pemfile is not None:
-            os.unlink(pemfile)
\ No newline at end of file
+        subprocess.call(["ssh", "-i", pemfile, "ec2-user@%s" % host])
\ No newline at end of file
