@@ -12,7 +12,7 @@ from qds_ops.entities.rds import RDS
 
 class Web(Tier):
     tier = "web"
-    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "pig", "tapp2"]
+    modules = ["hive_scripts", "hadoop", "hustler", "hive", "sqoop", "pig", "tapp2", "cloudman"]
     worker = "qpal_worker"
 
     def __init__(self, subparser):
